-- widget title=Assessment overview, row=40, col=2, size_x=8, size_y=3

## Other
- Object permissions
- Delta Live Tables
- Global Init Scripts
- Warning messages

[documentation](https://github.com/databrickslabs/ucx/blob/main/docs/assessment.md)
